#ifndef _KERNEL_COMMUNICATE_H
#define _KERNEL_COMMUNICATE_H

/* kysec special label type */
enum {
	EXECTL_VERIFIED_TYPE = 1,
	EXECTL_ORIGINAL_TYPE,
	EXECTL_KYSOFT_TYPE,
	EXECTL_TRUSTED_TYPE,
	EXECTL_UNKNOWN_TYPE
};

enum kysec_message_type {
	NETCTL_INIT = 0,
	NETCTL_ADD,
	NETCTL_DEL,
	KYSEC_NOTIFY,
	LABEL_INIT,
	LABEL_ADD,
	LABEL_DEL
};

enum kysec_notify_type {
	NOTIFY_LABEL = 0,
	NOTIFY_NETCTL
};

#ifdef __cplusplus
extern "C" {
#endif

/*
 * 功能：内核通讯接口
 * cmd: 防卸载命令
 */
int kysec_kmod_communicate_with_kernel(char *cmd);

/*
 * 功能：讲exectl标记转换为内核标记类型
 * exectl_label：exectl标记
 */
int kysec_convert_exectl_label_to_label_type(char *exectl_label);

/*
 * 功能：内核通讯接口
 * 
 */
int kysec_hash_communicate_with_kernel(int mesg_type, char *hash, int label_type);

/*
 * 功能：应用网络管控内核通讯接口
 * @mesg_type: 取值enum kysec_message_type，表示消息的操作类型
 * @hash: 从xml文件中读取出来的hash值
 * @netctl_type: 应用网络管控类型
 */
int kysec_netctl_communicate_with_kernel(int mesg_type, char *hash, int netctl_type);

#ifdef __cplusplus
}
#endif

#endif
